export class ExframeBase extends Error {
  public name: string;
  public message: string;
  public errorCode?: string;
  public statusCode?: number;

  constructor(message: string, errorCode?: string, statusCode?: number);
}

export class Axios extends ExframeBase {
  constructor(error: Error, options?: { message?: string, customErrorCode?: string | number });
}

export class Conflict extends ExframeBase {
  public statusCode = 409;

  constructor(message: string, errorCode = 'CONFLICT');
}

export class Forbidden extends ExframeBase {
  public statusCode = 403;

  constructor(message: string, errorCode = 'FORBIDDEN');
}

export class InvalidInput extends ExframeBase {
  public statusCode = 400;
  public dataPath?: any;
  constructor(message: string, options?: { errorCode?: string, dataPath?: any });
}

export class ResourceNotFound extends ExframeBase {
  public statusCode = 404;

  constructor(message: string, errorCode = 'NOT_FOUND');
}

export class Rpc extends ExframeBase {
  public errors: any;
  public result: any;

  constructor(response?: any, options?: { message?: string, customErrorCode?: string });
}

export class Unauthorized extends ExframeBase {
  public statusCode = 401;

  constructor(message: string, errorCode = 'UNAUTHORIZED');
}